# -*- coding: utf-8 -*-

# Copyright © 2010-2011 Red Hat, Inc.
#
# This software is licensed to you under the GNU General Public License,
# version 2 (GPLv2). There is NO WARRANTY for this software, express or
# implied, including the implied warranties of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv2
# along with this software; if not, see
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.
#
# Red Hat trademarks are not licensed under GPLv2. No permission is
# granted to use or replicate Red Hat trademarks that are incorporated
# in this software or its documentation.


# This is an example migration module.
# Each migration module must implement the following members:
# 1. version - integer representing the version the module migrates to
# 2. migrate() - function with no arguments that performs the migration

import logging
from gettext import gettext as _

from pulp.server.db.model import Repo


_log = logging.getLogger('pulp')


def _migrate_repos():
    collection = Repo.get_collection()
    for repo in collection.find({}):
        if repo.has_key('sync_in_progress') and type(repo['sync_in_progress']) == type(True):
            continue
        _log.info(_('Set sync_in_progress to False for  %s') % repo['name'])
        repo['sync_in_progress'] = False
        collection.save(repo, safe=True)


version = 10

def migrate():
    # There's a bit of the chicken and the egg problem here, since versioning
    # wasn't built into pulp from the beginning, we just have to bite the
    # bullet and call some initial state of the data model 'version 1'.
    # So this function is essentially a no-op.
    _log.info('migration to data model version %d started' % version)
    _migrate_repos()
    _log.info('migration to data model version %d complete' % version)
